#!/bin/sh
#       UnInstallation shell script for Hyperion IS on Unix
#
ME=`basename $0`' (Hyperion IS UnInstallation)'
USAGE="Usage:  $ME "


## -- Ask for input from user
# $1: prompt	$2: default	$3+: other choices
# Returning value comes back as $input
# USAGE:  ask 'Prompt' "default" ...
ask () {
        echo ""
	_pr="$1"
	_def="$2"
	prompt="${_pr}"
	shift
	if [ $# -gt 0 ]; then prompt="$prompt"' ['"${_def}"']' ; shift ; fi
	if [ $# -gt 0 ]; then prompt="$prompt"' {'"${_def} ""$@"'}' ; fi
	echo 1>&2 "$prompt ?"
	while read input ; do
		if [ -z "$input" ]; then input="${_def}" ; break ; fi
		if [ $# -eq 0 ]; then break ; fi
# @@@@ extend to limit to choices given
		break;
	done
}

## -- Error and information reporting
FATAL () {
        echo ""
	echo 1>&2 "$ME:  FATAL: $1"
	shift
	while [ $# -gt 0 ]; do
		echo 1>&2 "$ME: (FATAL)   $1"
		shift
	done
	echo 1>&2 "$ME: EXITING ...."
	exit 1
}

ERROR () {
        echo ""
	echo 1>&2 "$ME:  ERROR: $1"
	shift
	while [ $# -gt 0 ]; do
		echo 1>&2 "$ME: (ERROR)   $1"
		shift
	done
}

WARN () {
        echo ""
	echo 1>&2 "$ME:  WARNING: $1"
	shift
	while [ $# -gt 0 ]; do
		echo 1>&2 "$ME: (WARNING)   $1"
		shift
	done
}

FYI () {
        echo ""
	echo 1>&2 "$ME:  FYI: $1"
	shift
	while [ $# -gt 0 ]; do
		echo 1>&2 "$ME: (FYI)   $1"
		shift
	done
}




# Get the target directory
#
if [ ".$ISHOME" = "." ]
then
ISHOME=`pwd`
fi

ask "Enter the full path of ISHOME:  " "$ISHOME"
ISHOME=$input
if [ ! -d $ISHOME ]
  then
      ERROR "$ISHOME directory does not exist."
      exit 20p1
fi

#

cd $ISHOME

echo "Following products has been installed in $ISHOME:"
if [ -f .*isinst ] 
then
    echo "          - Hyperion Integration Server"
fi
if [ -f .*ocinst ] 
then
    echo "          - OLAP Catalog scripts"
fi
if [ -f .*isodbc ] 
then
    echo "          - INTERSOLV ODBC drivers "
fi
if [ -f .*sampleinst ] 
then
    echo "          - Sample Application"
fi
if [ -f .*isdocs ] 
then
    echo "          - Hyperion Integration Server documentation"
fi

echo ""
if [ -f .20p1isinst ]
then
ask 'Do you want to uninstall Hyperion Integration Server' "no" "yes"
if [ "$input" = "yes" ] || [ "$input" = "y" ]
then
   /usr/bin/rm -rf bin esslib locale islib
   if [ -d bin ] || [ -d esslib ] || [ -d locale ] || [ -d islib ]
   then
       WARN "Unable to uninstall Hyperion Integration Server." 
       exit 203
   fi
   /usr/bin/rm -rf .20p1isinst
   if [ -f .20p1isinst ]
   then
       WARN "Unable to uninstall Hyperion Integration Server."
       exit 203
   fi
   FYI "Hyperion Integration Server uninstalled." 
fi
fi

echo ""
if [ -f .20p1ocinst ]
then
ask 'Do you want to uninstall OLAP Catalog scripts' "no" "yes"
if [ "$input" = "yes" ] || [ "$input" = "y" ]
then
   /usr/bin/rm -rf ocscript
   if [ -d ocscript ]
    then
        WARN "Unable to uninstall OLAP Catalog scripts."
        exit 202
    fi
   /usr/bin/rm -rf .20p1ocinst
   if [ -f .20p1ocinst ]
   then
       WARN "Unable to uninstall OLAP Catalog scripts."
   fi
   FYI "OLAP Catalog scripts uninstalled."
fi
fi

echo ""
if [ -f .20p1isodbc ]
then
ask 'Do you want to uninstall INTERSOLV ODBC drivers' "no" "yes"
if [ "$input" = "yes" ] || [ "$input" = "y" ]
then
   /usr/bin/rm -rf odbcdocs odbclib lib odbc.ini odbcinst.ini 
   if [ -f odbc.ini ] || [ -d odbclib ] || [ -f odbcinst.ini ] || [ -d odbcdocs ]
   then
       WARN "Unable to uninstall INTERSOLV ODBC drivers" 
       exit 203
   fi
   if [ -d esslib ]
   then
   find esslib -type l -exec rm -f {} \;
   fi
   /usr/bin/rm -rf .20p1isodbc
   if [ -f .20p1isodbc ]
   then
       WARN "Unable to uninstall INTERSOLV ODBC Drivers."
       exit 203
   fi
   FYI "INTERSOLV ODBC drivers Uninstalled." 
   echo "Please remove the ODBCHOME and ODBCINI environment variables from is.sh is.csh"
fi
fi

echo " "
if [ -f .20p1sampleinst ]
then
ask 'Do you want to uninstall Sample Applicaton' "no" "yes"
if [ "$input" = "yes" ] || [ "$input" = "y" ]
then
   /usr/bin/rm -rf samples 
   if [ -d samples ]
   then
       WARN "Unable to uninstall Sample Application."
       exit 201
   fi
   /usr/bin/rm -rf .20p1sampleinst
   if [ -f .20p1sampleinst ]
   then
       WARN "Unable to uninstall Sample Application."
       exit 201
   fi
   FYI "Sample Application uninstalled."
fi
fi

echo ""
if [ -f .20p1isdocs ]
then
ask 'Do you want to uninstall Hyperion Integration Server documentation' "no" "yes"
if [ "$input" = "yes" ] || [ "$input" = "y" ]
then
   /usr/bin/rm -rf books
   /usr/bin/rm -rf odbcdocs
   if [ -d books ] || [ -d odbcdocs ]
   then
       WARN "Unable to uninstall Hyperion Integration Server documentation." 
       exit 203
   fi
   /usr/bin/rm -rf .20p1isdocs
   if [ -f .010isdocs ]
   then
       WARN "Unable to uninstall Hyperion Integration Server documentation."
       exit 203
   fi
   FYI "Hyperion Integration Server uninstalled documentation." 
fi
fi

echo ""
echo "Batch and esscript directories has not been removed."
echo "It may contain user created files."


#Done
echo 1>&2 "$ME": done
exit 0
