-- ============================================================
--   Database name:  HISCATALOG                                
--   DBMS name:      INFORMIX SQL 5.0, 6.0                     
--   Created on:     10/4/99  12:05 AM                         
-- ============================================================

-- ============================================================
--   Table: CB_CONCURRENCY                                     
-- ============================================================
create table CB_CONCURRENCY
(
    CB_USER_NAME        VARCHAR(30)            not null,
    CB_USER_SESSION_ID  INTEGER                not null,
    CB_OBJECT_ID        INTEGER                not null,
    CB_OBJECT_TYPE      INTEGER                not null,
    CB_OBJECT_LOCK      INTEGER                not null,
    CB_LOCK_TIMESTAMP   DATETIME               not null,
    primary key (CB_USER_NAME, CB_USER_SESSION_ID, CB_OBJECT_ID, CB_OBJECT_TYPE) constraint PK_CB_CONCURRENCY
);

-- ============================================================
--   Table: CB_VERSION                                         
-- ============================================================
create table CB_VERSION
(
    MD_VERSION          VARCHAR(30)            not null,
    MD_VERSION_DATE     DATETIME               not null,
    primary key (MD_VERSION) constraint PK_CB_VERSION
);

-- ============================================================
--   Table: OM_INFO                                            
-- ============================================================
create table OM_INFO
(
    MODEL_ID            INTEGER                not null,
    MODEL_NAME          VARCHAR(80)            not null,
    MODEL_DESCRIPTION   VARCHAR(255)                   ,
    MODEL_DATA_SOURCE   VARCHAR(255)           not null,
    MODEL_OWNER         VARCHAR(30)            not null,
    MODEL_ACCESS_CODE   INTEGER                not null,
    MODEL_DATA_SRCTYPE  INTEGER                not null,
    MODEL_DB_HINT       VARCHAR(255)                   ,
    primary key (MODEL_ID) constraint PK_OM_INFO
);

-- ============================================================
--   Table: OD_INFO                                            
-- ============================================================
create table OD_INFO
(
    MODEL_ID            INTEGER                not null,
    DIMENSION_ID        INTEGER                not null,
    DIMENSION_NAME      VARCHAR(80)            not null,
    DIMENSION_TYPE      INTEGER                not null,
    primary key (MODEL_ID, DIMENSION_ID) constraint PK_OD_INFO
);

-- ============================================================
--   Table: OVL_REL_INFO                                       
-- ============================================================
create table OVL_REL_INFO
(
    MODEL_ID            INTEGER                not null,
    LOG_RELATION_ID     INTEGER                not null,
    LOG_VIEW_1          INTEGER                not null,
    LOG_VIEW_2          INTEGER                not null,
    primary key (MODEL_ID, LOG_RELATION_ID) constraint PK_OVL_REL_INFO
);

-- ============================================================
--   Table: OV_INFO                                            
-- ============================================================
create table OV_INFO
(
    MODEL_ID            INTEGER                not null,
    VIEW_ID             INTEGER                not null,
    VIEW_NAME           VARCHAR(30)            not null,
    VIEW_DCX            INTEGER                not null,
    VIEW_DCY            INTEGER                not null,
    VIEW_TYPE           INTEGER                not null,
    primary key (MODEL_ID, VIEW_ID) constraint PK_OV_INFO
);

-- ============================================================
--   Table: MO_INFO                                            
-- ============================================================
create table MO_INFO
(
    MO_ID               INTEGER                not null,
    MODEL_ID            INTEGER                not null,
    MO_NAME             VARCHAR(80)            not null,
    MO_DESC             VARCHAR(255)                   ,
    MO_CHANGE_DATE      DATETIME               not null,
    MO_OWNER            VARCHAR(30)            not null,
    MO_ACCESS_CODE      INTEGER                not null,
    DT_CBS_PROMPT       INTEGER                not null,
    DT_SRC_PROMPT       INTEGER                not null,
    primary key (MO_ID) constraint PK_MO_INFO
);

-- ============================================================
--   Table: OMB_INFO                                           
-- ============================================================
create table OMB_INFO
(
    MODEL_ID            INTEGER                not null,
    DIMENSION_ID        INTEGER                not null,
    MODEL_BLOCK_ID      INTEGER                not null,
    MODEL_BLOCK_NAME    VARCHAR(255)           not null,
    primary key (MODEL_ID, DIMENSION_ID, MODEL_BLOCK_ID) constraint PK_OMB_INFO
);

-- ============================================================
--   Table: OMB_DETAILS                                        
-- ============================================================
create table OMB_DETAILS
(
    MODEL_ID            INTEGER                not null,
    DIMENSION_ID        INTEGER                not null,
    MODEL_BLOCK_ID      INTEGER                not null,
    MB_ATTRIBUTE_ID     INTEGER                not null,
    VIEW_ID             INTEGER                not null,
    ATTRIBUTE_ID        INTEGER                not null,
    MB_ATTRIBUTE_LVL    INTEGER                not null,
    MB_BUILD_ORDER      INTEGER                not null,
    primary key (MODEL_ID, DIMENSION_ID, MODEL_BLOCK_ID, MB_ATTRIBUTE_ID) constraint PK_OMB_DETAILS
);

-- ============================================================
--   Table: OA_INFO                                            
-- ============================================================
create table OA_INFO
(
    MODEL_ID            INTEGER                not null,
    VIEW_ID             INTEGER                not null,
    ATTRIBUTE_ID        INTEGER                not null,
    ATTRIBUTE_NAME      VARCHAR(80)            not null,
    ATTRIBUTE_DATATYPE  VARCHAR(10)            not null,
    AGGREGATE_TYPE      VARCHAR(10)            not null,
    PHYSICAL_TABLE      VARCHAR(255)           not null,
    PHYSICAL_COLUMN     VARCHAR(30)            not null,
    ATTRIBUTE_DISPLAY   INTEGER                not null,
    ATTRIBUTE_TYPE      INTEGER                not null,
    ATTRIBUTE_EX_RULE   VARCHAR(255)                   ,
    primary key (MODEL_ID, VIEW_ID, ATTRIBUTE_ID) constraint PK_OA_INFO
);

-- ============================================================
--   Table: OVP_REL_INFO                                       
-- ============================================================
create table OVP_REL_INFO
(
    MODEL_ID            INTEGER                not null,
    VIEW_ID             INTEGER                not null,
    PHY_RELATION_ID     INTEGER                not null,
    PHY_REL_TYPE        INTEGER                not null,
    PHY_TABLE_1         VARCHAR(255)           not null,
    PHY_TABLE_2         VARCHAR(255)           not null,
    primary key (MODEL_ID, VIEW_ID, PHY_RELATION_ID) constraint PK_OVP_REL_INFO
);

-- ============================================================
--   Table: MOD_INFO                                           
-- ============================================================
create table MOD_INFO
(
    MO_ID               INTEGER                not null,
    MOD_ID              INTEGER                not null,
    DIMENSION_ID        INTEGER                        ,
    MOD_TYPE            INTEGER                not null,
    MOD_NAME            VARCHAR(80)            not null,
    MOD_SEQ_NUMBER      INTEGER                not null,
    primary key (MO_ID, MOD_ID) constraint PK_MOD_INFO
);

-- ============================================================
--   Table: MSR_INFO                                           
-- ============================================================
create table MSR_INFO
(
    MO_ID               INTEGER                not null,
    MSR_ID              INTEGER                not null,
    MSR_NAME            VARCHAR(80)            not null,
    MSR_SEQ_NUMBER      INTEGER                not null,
    MSR_VIEW_ID         INTEGER                not null,
    MSR_ATTRIBUTE_ID    INTEGER                not null,
    primary key (MO_ID, MSR_ID) constraint PK_MSR_INFO
);

-- ============================================================
--   Table: MO_FILTERS                                         
-- ============================================================
create table MO_FILTERS
(
    MO_ID               INTEGER                not null,
    FLT_ID              INTEGER                not null,
    FLT_TYPE            INTEGER                not null,
    FLT_NAME            VARCHAR(80)                    ,
    primary key (MO_ID, FLT_ID) constraint PK_MO_FILTERS
);

-- ============================================================
--   Table: DTR_INFO                                           
-- ============================================================
create table DTR_INFO
(
    MO_ID               INTEGER                not null,
    DTR_ID              INTEGER                not null,
    DTR_NAME            VARCHAR(80)            not null,
    DTR_SKIP_WIZARD     INTEGER                not null,
    DTR_ROW_GOVERNOR    INTEGER                not null,
    DTR_TIME_GOVERNOR   INTEGER                not null,
    primary key (MO_ID, DTR_ID) constraint PK_DTR_INFO
);

-- ============================================================
--   Table: MS_INFO                                            
-- ============================================================
create table MS_INFO
(
    MO_ID               INTEGER                not null,
    MOD_ID              INTEGER                not null,
    MS_ID               INTEGER                not null,
    MS_TYPE             INTEGER                not null,
    MS_NAME             VARCHAR(80)            not null,
    MS_PARENT_ID        INTEGER                not null,
    MS_SEQ_NUMBER       INTEGER                not null,
    MS_MSR_ID           INTEGER                not null,
    MS_VIEW_ID          INTEGER                not null,
    MS_ATTRIBUTE_ID     INTEGER                not null,
    primary key (MO_ID, MOD_ID, MS_ID) constraint PK_MS_INFO
);

-- ============================================================
--   Table: OD_DETAILS                                         
-- ============================================================
create table OD_DETAILS
(
    MODEL_ID            INTEGER                not null,
    DIMENSION_ID        INTEGER                not null,
    DIM_DETAIL_ID       INTEGER                not null,
    VIEW_ID             INTEGER                        ,
    DIM_PARENT_VIEW_ID  INTEGER                not null,
    primary key (MODEL_ID, DIMENSION_ID, DIM_DETAIL_ID) constraint PK_OD_DETAILS
);

-- ============================================================
--   Table: OVL_REL_DETAILS                                    
-- ============================================================
create table OVL_REL_DETAILS
(
    MODEL_ID            INTEGER                not null,
    LOG_RELATION_ID     INTEGER                not null,
    LOG_REL_DET_ID      INTEGER                not null,
    LOG_ATTRIBUTE_1     INTEGER                not null,
    LOG_ATTRIBUTE_2     INTEGER                not null,
    primary key (MODEL_ID, LOG_RELATION_ID, LOG_REL_DET_ID) constraint PK_OVL_REL_DETAILS
);

-- ============================================================
--   Table: OVP_REL_DETAILS                                    
-- ============================================================
create table OVP_REL_DETAILS
(
    MODEL_ID            INTEGER                not null,
    VIEW_ID             INTEGER                not null,
    PHY_RELATION_ID     INTEGER                not null,
    PHY_REL_DET_ID      INTEGER                not null,
    PHY_COLUMN_1        VARCHAR(30)            not null,
    PHY_COLUMN_2        VARCHAR(30)            not null,
    primary key (MODEL_ID, VIEW_ID, PHY_RELATION_ID, PHY_REL_DET_ID) constraint PK_OVP_REL_DETAILS
);

-- ============================================================
--   Table: MO_PROPERTIES                                      
-- ============================================================
create table MO_PROPERTIES
(
    MO_ID               INTEGER                not null,
    MOD_ID              INTEGER                not null,
    MS_ID               INTEGER                not null,
    PRP_CODE            INTEGER                not null,
    PRP_CD_INS_NUMBER   INTEGER                not null,
    PRP_CD_SEQ_NUMBER   INTEGER                not null,
    PRP_VALUE           VARCHAR(255)                   ,
    PRP_VIEW_ID         INTEGER                not null,
    PRP_ATTRIBUTE_ID    INTEGER                not null,
    primary key (MO_ID, MOD_ID, MS_ID, PRP_CODE, PRP_CD_INS_NUMBER, PRP_CD_SEQ_NUMBER) constraint PK_MO_PROPERTIES
);

-- ============================================================
--   Table: MS_TX_RULE                                         
-- ============================================================
create table MS_TX_RULE
(
    MO_ID               INTEGER                not null,
    MOD_ID              INTEGER                not null,
    MS_ID               INTEGER                not null,
    TXR_SEQ_NUMBER      INTEGER                not null,
    TXR_DEFINITION      VARCHAR(255)           not null,
    primary key (MO_ID, MOD_ID, MS_ID, TXR_SEQ_NUMBER) constraint PK_MS_TX_RULE
);

-- ============================================================
--   Table: MSR_TX_RULE                                        
-- ============================================================
create table MSR_TX_RULE
(
    MO_ID               INTEGER                not null,
    MSR_ID              INTEGER                not null,
    MSR_TXR_SEQ_NUMBER  INTEGER                not null,
    MSR_TXR_DEFINITION  VARCHAR(255)           not null,
    primary key (MO_ID, MSR_ID, MSR_TXR_SEQ_NUMBER) constraint PK_MSR_TX_RULE
);

-- ============================================================
--   Table: MB_TX_RULE                                         
-- ============================================================
create table MB_TX_RULE
(
    MODEL_ID            INTEGER                not null,
    DIMENSION_ID        INTEGER                not null,
    MODEL_BLOCK_ID      INTEGER                not null,
    MB_ATTRIBUTE_ID     INTEGER                not null,
    MB_TXR_SEQ_NUMBER   INTEGER                not null,
    MB_TXR_DEFINITION   VARCHAR(255)           not null,
    primary key (MODEL_ID, DIMENSION_ID, MODEL_BLOCK_ID, MB_ATTRIBUTE_ID, MB_TXR_SEQ_NUMBER) constraint PK_MB_TX_RULE
);

-- ============================================================
--   Table: MB_FILTER                                          
-- ============================================================
create table MB_FILTER
(
    MODEL_ID            INTEGER                not null,
    DIMENSION_ID        INTEGER                not null,
    MODEL_BLOCK_ID      INTEGER                not null,
    MB_ATTRIBUTE_ID     INTEGER                not null,
    MBF_SEQ_NUMBER      INTEGER                not null,
    MBF_DEFINITION      VARCHAR(255)           not null,
    primary key (MODEL_ID, DIMENSION_ID, MODEL_BLOCK_ID, MB_ATTRIBUTE_ID, MBF_SEQ_NUMBER) constraint PK_MB_FILTER
);

-- ============================================================
--   Table: MS_PREDICATES                                      
-- ============================================================
create table MS_PREDICATES
(
    MO_ID               INTEGER                not null,
    FLT_ID              INTEGER                not null,
    MOD_ID              INTEGER                not null,
    MS_ID               INTEGER                not null,
    MS_PRD_TYPE         INTEGER                not null,
    MS_PRD_SEQ_NUMBER   INTEGER                not null,
    MS_PRD_DEFINITION   VARCHAR(255)           not null,
    primary key (MO_ID, FLT_ID, MOD_ID, MS_ID, MS_PRD_TYPE, MS_PRD_SEQ_NUMBER) constraint PK_MS_PREDICATES
);

-- ============================================================
--   Table: MSR_PREDICATES                                     
-- ============================================================
create table MSR_PREDICATES
(
    MO_ID               INTEGER                not null,
    FLT_ID              INTEGER                not null,
    MSR_ID              INTEGER                not null,
    MSR_PRD_SEQ_NUMBER  INTEGER                not null,
    MSR_PRD_DEFINITION  VARCHAR(255)           not null,
    primary key (MO_ID, FLT_ID, MSR_ID, MSR_PRD_SEQ_NUMBER) constraint PK_MSR_PREDICATES
);

-- ============================================================
--   Table: MO_INTERSECTION                                    
-- ============================================================
create table MO_INTERSECTION
(
    MO_ID               INTEGER                not null,
    DTR_ID              INTEGER                not null,
    DTI_MOD_ID          INTEGER                not null,
    DTI_MS_ID           INTEGER                not null,
    primary key (MO_ID, DTR_ID, DTI_MOD_ID, DTI_MS_ID) constraint PK_MO_INTERSECTION
);

-- ============================================================
--   Table: DTR_ATTRIBUTES                                     
-- ============================================================
create table DTR_ATTRIBUTES
(
    MO_ID               INTEGER                not null,
    DTR_ID              INTEGER                not null,
    DTR_VIEW_ID         INTEGER                not null,
    DTR_ATTRIBUTE_ID    INTEGER                not null,
    DTR_DISP_ORDER      INTEGER                not null,
    DTR_SORT_ORDER      INTEGER                not null,
    DTR_ORDER_BY        INTEGER                not null,
    primary key (MO_ID, DTR_ID, DTR_VIEW_ID, DTR_ATTRIBUTE_ID) constraint PK_DTR_ATTRIBUTES
);

-- ============================================================
--   Table: JOIN_HINTS                                         
-- ============================================================
create table JOIN_HINTS
(
    MODEL_ID            INTEGER                not null,
    HINT_VIEW_ID        INTEGER                not null,
    JOIN_TYPE           INTEGER                not null,
    JOIN_ID             INTEGER                not null,
    PHYSICAL_TABLE      VARCHAR(255)           not null,
    HINT_TEXT           VARCHAR(255)           not null,
    HINT_ID             INTEGER                not null,
    primary key (MODEL_ID, HINT_VIEW_ID, JOIN_TYPE, JOIN_ID, HINT_ID) constraint PK_JOIN_HINTS
);

-- ============================================================
--   Table: OM_DESCRIPTIONS                                    
-- ============================================================
create table OM_DESCRIPTIONS
(
    MODEL_ID            INTEGER                not null,
    DIMENSION_ID        INTEGER                not null,
    VIEW_ID             INTEGER                not null,
    ATTRIBUTE_ID        INTEGER                not null,
    MODEL_BLOCK_ID      INTEGER                not null,
    DESCRIPTION         VARCHAR(255)                   ,
    primary key (MODEL_ID, DIMENSION_ID, VIEW_ID, ATTRIBUTE_ID, MODEL_BLOCK_ID) constraint PK_OM_DESCRIPTIONS
);

-- ============================================================
--   Table: MOD_ATTRIBUTES                                     
-- ============================================================
create table MOD_ATTRIBUTES
(
    MO_ID               INTEGER                not null,
    MOD_ID              INTEGER                not null,
    MOD_ATTRIBUTE_ID    INTEGER                not null,
    MOD_ATTR_DATATYPE   INTEGER                not null,
    MOD_ATTR_ALIAS      VARCHAR(80)                    ,
    MOD_ATTR_TXR        VARCHAR(255)                   ,
    primary key (MO_ID, MOD_ATTRIBUTE_ID) constraint PK_MOD_ATTRIBUTES
);

-- ============================================================
--   Table: MO_DESCRIPTIONS                                    
-- ============================================================
create table MO_DESCRIPTIONS
(
    MO_ID               INTEGER                not null,
    FLT_ID              INTEGER                not null,
    MOD_ID              INTEGER                not null,
    MS_ID               INTEGER                not null,
    DESCRIPTIONS        VARCHAR(255)                   ,
    primary key (MO_ID, FLT_ID, MOD_ID, MS_ID) constraint PK_MO_DESCRIPTIONS
);

