-- ============================================================
--   Database name:  TBC (HIS 20)                                  
--   DBMS name:      DB2 Universal Database                
--   Created on:     5/25/00  5:59 PM                          
-- ============================================================

-- ============================================================
--   Table: PRODUCTDIM                                         
-- ============================================================
create table PRODUCTDIM
(
    FAMILY            VARCHAR(15)                       ,
    FAMILYNAME        VARCHAR(25)                       ,
    FAMILYATTR        VARCHAR(1)                        ,
    SKU               VARCHAR(15)                       ,
    SKUNAME           VARCHAR(25)                       
);

-- ============================================================
--   Table: FAMILY                                             
-- ============================================================
create table FAMILY
(
    FAMILYID          INTEGER               not null ,
    FAMILY            VARCHAR(15)                       ,
    FAMILYNAME        VARCHAR(25)                       ,
    INTRODATE         DATE                           ,
    constraint PK_1 primary key (FAMILYID)
);

-- ============================================================
--   Table: POPULATION                                         
-- ============================================================
create table POPULATION
(
    POPULATIONID      INTEGER               not null ,
    POPGROUP          VARCHAR(15)                       ,
    POPULATION        INTEGER                        ,
    POPULATIONNAME    VARCHAR(25)                       ,
    constraint PK_11 primary key (POPULATIONID)
);

-- ============================================================
--   Table: REGION                                             
-- ============================================================
create table REGION
(
    REGIONID          INTEGER               not null ,
    REGION            VARCHAR(15)                       ,
    DIRECTOR          VARCHAR(50)                       ,
    constraint PK_31 primary key (REGIONID)
);

-- ============================================================
--   Table: SCENARIO                                           
-- ============================================================
create table SCENARIO
(
    SCENARIOID        INTEGER               not null ,
    SCENARIO          VARCHAR(15)                       ,
    ATTRIBUTE         VARCHAR(1)                        ,
    constraint PK_48 primary key (SCENARIOID)
);

-- ============================================================
--   Table: SUPPLIER                                           
-- ============================================================
create table SUPPLIER
(
    SUPPLIERID        INTEGER               not null ,
    SUPPLIERNAME      VARCHAR(50)                       ,
    ADDRESS           VARCHAR(25)                       ,
    CITY              VARCHAR(25)                       ,
    STATE             VARCHAR(25)                       ,
    ZIP               VARCHAR(20)                       ,
    COUNTRY           VARCHAR(25)                       ,
    constraint PK_52 primary key (SUPPLIERID)
);

-- ============================================================
--   Table: PRODUCT                                            
-- ============================================================
create table PRODUCT
(
    PRODUCTID         INTEGER               not null ,
    FAMILYID          INTEGER                        ,
    SKU               VARCHAR(15)                       ,
    SKUNAME           VARCHAR(25)                       ,
    CAFFEINATED       VARCHAR(5)                        ,
    OUNCES            INTEGER                        ,
    PKGTYPE           VARCHAR(15)                       ,
    INTRODATE         DATE                           ,
    constraint PK_16 primary key (PRODUCTID)
);

-- ============================================================
--   Table: MARKET                                             
-- ============================================================
create table MARKET
(
    STATEID           INTEGER               not null ,
    REGIONID          INTEGER                        ,
    STATE             VARCHAR(25)                       ,
    POPULATIONID      INTEGER                        ,
    constraint PK_6 primary key (STATEID)
);

-- ============================================================
--   Table: SALESFACT                                          
-- ============================================================
create table SALESFACT
(
    STATEID           INTEGER                        ,
    PRODUCTID         INTEGER                        ,
    SCENARIOID        INTEGER                        ,
    SUPPLIERID        INTEGER                        ,
    TRANSDATE         DATE                           ,
    SALES             DECIMAL(7,2)               ,
    COGS              DECIMAL(7,2)               ,
    MARKETING         DECIMAL(7,2)               ,
    PAYROLL           DECIMAL(7,2)               ,
    MISC              DECIMAL(7,2)               ,
    OPENINGINVENTORY  DECIMAL(7,2)               ,
    ADDITIONS         DECIMAL(7,2)               
);

alter table PRODUCT
    foreign key FK_72 (FAMILYID)
       references FAMILY (FAMILYID) on delete restrict;

alter table MARKET
    foreign key FK_75 (REGIONID)
       references REGION (REGIONID) on delete restrict;

alter table MARKET
    foreign key FK_78 (POPULATIONID)
       references POPULATION (POPULATIONID) on delete restrict;

alter table SALESFACT
    foreign key FK_60 (SUPPLIERID)
       references SUPPLIER (SUPPLIERID) on delete restrict;

alter table SALESFACT
    foreign key FK_63 (STATEID)
       references MARKET (STATEID) on delete restrict;

alter table SALESFACT
    foreign key FK_66 (SCENARIOID)
       references SCENARIO (SCENARIOID) on delete restrict;

alter table SALESFACT
    foreign key FK_69 (PRODUCTID)
       references PRODUCT (PRODUCTID) on delete restrict;

