-- ============================================================
--   Database name:  TBC (HIS 20)                                   
--   DBMS name:      ORACLE Version 8                          
--   Created on:     6/5/00  12:46 AM                          
-- ============================================================

-- ============================================================
--   Table: PRODUCTDIM                                         
-- ============================================================
create table PRODUCTDIM
(
    FAMILY            VARCHAR2(15)               null    ,
    FAMILYNAME        VARCHAR2(25)               null    ,
    FAMILYATTR        VARCHAR2(1)                null    ,
    SKU               VARCHAR2(15)               null    ,
    SKUNAME           VARCHAR2(25)               null    
)
/

-- ============================================================
--   Table: FAMILY                                             
-- ============================================================
create table FAMILY
(
    FAMILYID          INTEGER                not null,
    FAMILY            VARCHAR2(15)               null    ,
    FAMILYNAME        VARCHAR2(25)               null    ,
    INTRODATE         DATE                   null    ,
    constraint PK_FAMILY primary key (FAMILYID)
)
/

-- ============================================================
--   Table: POPULATION                                         
-- ============================================================
create table POPULATION
(
    POPULATIONID      INTEGER                not null,
    POPGROUP          VARCHAR2(15)               null    ,
    POPULATION        INTEGER                null    ,
    POPULATIONNAME    VARCHAR2(25)               null    ,
    constraint PK_POPULATION primary key (POPULATIONID)
)
/

-- ============================================================
--   Table: REGION                                             
-- ============================================================
create table REGION
(
    REGIONID          INTEGER                not null,
    REGION            VARCHAR2(15)               null    ,
    DIRECTOR          VARCHAR2(50)               null    ,
    constraint PK_REGION primary key (REGIONID)
)
/

-- ============================================================
--   Table: SCENARIO                                           
-- ============================================================
create table SCENARIO
(
    SCENARIOID        INTEGER                not null,
    SCENARIO          VARCHAR2(15)               null    ,
    ATTRIBUTE         VARCHAR2(1)                null    ,
    constraint PK_SCENARIO primary key (SCENARIOID)
)
/

-- ============================================================
--   Table: SUPPLIER                                           
-- ============================================================
create table SUPPLIER
(
    SUPPLIERID        INTEGER                not null,
    SUPPLIERNAME      VARCHAR2(50)               null    ,
    ADDRESS           VARCHAR2(25)               null    ,
    CITY              VARCHAR2(25)               null    ,
    STATE             VARCHAR2(25)               null    ,
    ZIP               VARCHAR2(20)               null    ,
    COUNTRY           VARCHAR2(25)               null    ,
    constraint PK_SUPPLIER primary key (SUPPLIERID)
)
/

-- ============================================================
--   Table: PRODUCT                                            
-- ============================================================
create table PRODUCT
(
    PRODUCTID         INTEGER                not null,
    FAMILYID          INTEGER                null    ,
    SKU               VARCHAR2(15)               null    ,
    SKUNAME           VARCHAR2(25)               null    ,
    CAFFEINATED       VARCHAR2(5)                null    ,
    OUNCES            INTEGER                null    ,
    PKGTYPE           VARCHAR2(15)               null    ,
    INTRODATE         DATE                   null    ,
    constraint PK_PRODUCT primary key (PRODUCTID)
)
/

-- ============================================================
--   Table: MARKET                                             
-- ============================================================
create table MARKET
(
    STATEID           INTEGER                not null,
    REGIONID          INTEGER                null    ,
    STATE             VARCHAR2(25)               null    ,
    POPULATIONID      INTEGER                null    ,
    constraint PK_MARKET primary key (STATEID)
)
/

-- ============================================================
--   Table: SALESFACT                                          
-- ============================================================
create table SALESFACT
(
    STATEID           INTEGER                null    ,
    PRODUCTID         INTEGER                null    ,
    SCENARIOID        INTEGER                null    ,
    SUPPLIERID        INTEGER                null    ,
    TRANSDATE         DATE                   null    ,
    SALES             FLOAT                  null    ,
    COGS              FLOAT                  null    ,
    MARKETING         FLOAT                  null    ,
    PAYROLL           FLOAT                  null    ,
    MISC              FLOAT                  null    ,
    OPENINGINVENTORY  FLOAT                  null    ,
    ADDITIONS         FLOAT                  null    
)
/

alter table PRODUCT
    add constraint FK_PRODUCT_REF_72_FAMILY foreign key  (FAMILYID)
       references FAMILY (FAMILYID)
/

alter table MARKET
    add constraint FK_MARKET_REF_75_REGION foreign key  (REGIONID)
       references REGION (REGIONID)
/

alter table MARKET
    add constraint FK_MARKET_REF_78_POPULATI foreign key  (POPULATIONID)
       references POPULATION (POPULATIONID)
/

alter table SALESFACT
    add constraint FK_SALESFAC_REF_60_SUPPLIER foreign key  (SUPPLIERID)
       references SUPPLIER (SUPPLIERID)
/

alter table SALESFACT
    add constraint FK_SALESFAC_REF_63_MARKET foreign key  (STATEID)
       references MARKET (STATEID)
/

alter table SALESFACT
    add constraint FK_SALESFAC_REF_66_SCENARIO foreign key  (SCENARIOID)
       references SCENARIO (SCENARIOID)
/

alter table SALESFACT
    add constraint FK_SALESFAC_REF_69_PRODUCT foreign key  (PRODUCTID)
       references PRODUCT (PRODUCTID)
/

