/* ============================================================ */
/*   Database name:  TBC (HIS 20)                               */
/*   DBMS name:      Microsoft SQL Server 7.x                   */
/*   Created on:     6/4/00  12:59 AM                           */
/* ============================================================ */

/* ============================================================ */
/*   Table: PRODUCTDIM                                          */
/* ============================================================ */
create table PRODUCTDIM
(
    FAMILY            varchar(15)              null    ,
    FAMILYNAME        varchar(25)              null    ,
    FAMILYATTR        varchar(1)               null    ,
    SKU               varchar(15)              null    ,
    SKUNAME           varchar(25)              null    
)
go

/* ============================================================ */
/*   Table: FAMILY                                              */
/* ============================================================ */
create table FAMILY
(
    FAMILYID          int                   not null,
    FAMILY            varchar(15)              null    ,
    FAMILYNAME        varchar(25)              null    ,
    INTRODATE         datetime              null    ,
    constraint PK_FAMILY primary key (FAMILYID)
)
go

/* ============================================================ */
/*   Table: POPULATION                                          */
/* ============================================================ */
create table POPULATION
(
    POPULATIONID      int                   not null,
    POPGROUP          varchar(15)              null    ,
    POPULATION        int                   null    ,
    POPULATIONNAME    varchar(25)              null    ,
    constraint PK_POPULATION primary key (POPULATIONID)
)
go

/* ============================================================ */
/*   Table: REGION                                              */
/* ============================================================ */
create table REGION
(
    REGIONID          int                   not null,
    REGION            varchar(15)              null    ,
    DIRECTOR          varchar(50)              null    ,
    constraint PK_REGION primary key (REGIONID)
)
go

/* ============================================================ */
/*   Table: SCENARIO                                            */
/* ============================================================ */
create table SCENARIO
(
    SCENARIOID        int                   not null,
    SCENARIO          varchar(15)              null    ,
    ATTRIBUTE         varchar(1)               null    ,
    constraint PK_SCENARIO primary key (SCENARIOID)
)
go

/* ============================================================ */
/*   Table: SUPPLIER                                            */
/* ============================================================ */
create table SUPPLIER
(
    SUPPLIERID        int                   not null,
    SUPPLIERNAME      varchar(50)              null    ,
    ADDRESS           varchar(25)              null    ,
    CITY              varchar(25)              null    ,
    STATE             varchar(25)              null    ,
    ZIP               varchar(20)              null    ,
    COUNTRY           varchar(25)              null    ,
    constraint PK_SUPPLIER primary key (SUPPLIERID)
)
go

/* ============================================================ */
/*   Table: PRODUCT                                             */
/* ============================================================ */
create table PRODUCT
(
    PRODUCTID         int                   not null,
    FAMILYID          int                   null    ,
    SKU               varchar(15)              null    ,
    SKUNAME           varchar(25)              null    ,
    CAFFEINATED       varchar(5)               null    ,
    OUNCES            int                   null    ,
    PKGTYPE           varchar(15)              null    ,
    INTRODATE         datetime              null    ,
    constraint PK_PRODUCT primary key (PRODUCTID)
)
go

/* ============================================================ */
/*   Table: MARKET                                              */
/* ============================================================ */
create table MARKET
(
    STATEID           int                   not null,
    REGIONID          int                   null    ,
    STATE             varchar(25)              null    ,
    POPULATIONID      int                   null    ,
    constraint PK_MARKET primary key (STATEID)
)
go

/* ============================================================ */
/*   Table: SALESFACT                                           */
/* ============================================================ */
create table SALESFACT
(
    STATEID           int                   null    ,
    PRODUCTID         int                   null    ,
    SCENARIOID        int                   null    ,
    SUPPLIERID        int                   null    ,
    TRANSDATE         datetime              null    ,
    SALES             double precision      null    ,
    COGS              double precision      null    ,
    MARKETING         double precision      null    ,
    PAYROLL           double precision      null    ,
    MISC              double precision      null    ,
    OPENINGINVENTORY  double precision      null    ,
    ADDITIONS         double precision      null    
)
go

alter table PRODUCT
    add constraint FK_PRODUCT_REF_72_FAMILY foreign key  (FAMILYID)
       references FAMILY (FAMILYID)
go

alter table MARKET
    add constraint FK_MARKET_REF_75_REGION foreign key  (REGIONID)
       references REGION (REGIONID)
go

alter table MARKET
    add constraint FK_MARKET_REF_78_POPULATI foreign key  (POPULATIONID)
       references POPULATION (POPULATIONID)
go

alter table SALESFACT
    add constraint FK_SALESFAC_REF_60_SUPPLIER foreign key  (SUPPLIERID)
       references SUPPLIER (SUPPLIERID)
go

alter table SALESFACT
    add constraint FK_SALESFAC_REF_63_MARKET foreign key  (STATEID)
       references MARKET (STATEID)
go

alter table SALESFACT
    add constraint FK_SALESFAC_REF_66_SCENARIO foreign key  (SCENARIOID)
       references SCENARIO (SCENARIOID)
go

alter table SALESFACT
    add constraint FK_SALESFAC_REF_69_PRODUCT foreign key  (PRODUCTID)
       references PRODUCT (PRODUCTID)
go

